tiled.client.xarray.DaskDataArrayClient
=======================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: DaskDataArrayClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DaskDataArrayClient.__init__
      ~DaskDataArrayClient.download
      ~DaskDataArrayClient.export_all
      ~DaskDataArrayClient.export_array
      ~DaskDataArrayClient.new_variation
      ~DaskDataArrayClient.read
      ~DaskDataArrayClient.read_block
      ~DaskDataArrayClient.refresh
      ~DaskDataArrayClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DaskDataArrayClient.context
      ~DaskDataArrayClient.coords
      ~DaskDataArrayClient.item
      ~DaskDataArrayClient.metadata
      ~DaskDataArrayClient.offline
      ~DaskDataArrayClient.path
      ~DaskDataArrayClient.uri
      ~DaskDataArrayClient.username
   
   